# Issuer

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | Unique identifier | [optional] [readonly] 
**issuer** | **str** | connect id issuer | 
**org_id** | **str** | ID of the organisation which owns the issuer | [optional] 
**clients** | [**list[IssuerClient]**](IssuerClient.md) |  | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


